iam

package
v1.1.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 26, 2024 License: MIT Imports: 2 Imported by: 0

README

awsutils/iam

The iam package is a collection of utility functions designed to simplify common iam tasks.


Table of contents


Functions

GetIamInstanceProfile(string)
GetIamInstanceProfile(string) *iam.InstanceProfile, error

GetIamInstanceProfile retrieves the IAM instance profile by its name


Installation

To use the awsutils/iam package, you first need to install it. Follow the steps below to install via go get.

go get github.com/l50/awsutils/iam

Usage

After installation, you can import the package in your Go project using the following import statement:

import "github.com/l50/awsutils/iam"

Tests

To ensure the package is working correctly, run the following command to execute the tests for awsutils/iam:

go test -v

Contributing

Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.


License

This project is licensed under the MIT License - see the LICENSE file for details.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetIamInstanceProfile

func GetIamInstanceProfile(profileName string) (*iam.InstanceProfile, error)

GetIamInstanceProfile retrieves the IAM instance profile by its name

Types

This section is empty.

Jump to